@@ -7,15 +7,11 @@ class ASFSearchError(ASFError):
 
 
 class ASFSearch4xxError(ASFSearchError):
-    """Raise when SearchAPI returns a 4xx error"""
+    """Raise when CMR returns a 4xx error"""
 
 
 class ASFSearch5xxError(ASFSearchError):
-    """Raise when SearchAPI returns a 5xx error"""
-
-
-class ASFServerError(ASFSearchError):
-    """Raise when SearchAPI returns an unknown error"""
+    """Raise when CMR returns a 5xx error"""
 
 
 class ASFBaselineError(ASFSearchError):
@@ -29,14 +25,18 @@ class ASFDownloadError(ASFError):
 class ASFAuthenticationError(ASFError):
     """Base download-related Exception"""
 
+
 class ASFWKTError(ASFError):
     """Raise when wkt related errors occur"""
 
+
 class CMRError(Exception):
     """Base CMR Exception"""
 
+
 class CMRConceptIDError(CMRError):
     """Raise when CMR encounters a concept-id error"""
 
+
 class CMRIncompleteError(CMRError):
     """Raise when CMR returns an incomplete page of results"""
