@@ -1,4 +1,4 @@
-from typing import Type
+from typing import Optional, Type
 from asf_search.baseline.stack import get_baseline_from_stack
 from asf_search import ASF_LOGGER
 from copy import copy
@@ -6,8 +6,8 @@ from copy import copy
 from asf_search.search import search, product_search
 from asf_search.ASFSearchOptions import ASFSearchOptions
 from asf_search.ASFSearchResults import ASFSearchResults
-from asf_search import ASFProduct
-from asf_search.constants import PLATFORM
+from asf_search import ASFProduct, ARIAS1GUNWProduct
+from asf_search.constants import PLATFORM, DATASET
 from asf_search.exceptions import ASFSearchError
 
 
@@ -69,8 +69,8 @@ def stack_from_product(
 
 def stack_from_id(
     reference_id: str,
-    opts: ASFSearchOptions = None,
-    useSubclass: Type[ASFProduct] = None,
+    opts: Optional[ASFSearchOptions] = None,
+    useSubclass: Optional[Type[ASFProduct]] = None,
 ) -> ASFSearchResults:
     """
     Finds a baseline stack from a reference product ID
@@ -94,9 +94,18 @@ def stack_from_id(
 
     opts = ASFSearchOptions() if opts is None else copy(opts)
 
-    reference_results = product_search(product_list=reference_id, opts=opts)
+    if opts.dataset is not None and DATASET.ARIA_S1_GUNW in opts.dataset:
+        reference_results = ARIAS1GUNWProduct.get_aria_groups_for_frame(reference_id)
 
-    reference_results.raise_if_incomplete()
+        if len(reference_results) == 0:
+            reference = None
+        else:
+            reference = reference_results[0]
+        
+        return get_baseline_from_stack(reference=reference, stack=reference_results)[0]
+    else:
+        reference_results = product_search(product_list=reference_id, opts=opts)
+        reference_results.raise_if_incomplete()
 
     if len(reference_results) <= 0:
         raise ASFSearchError(f'Reference product not found: {reference_id}')
